@@ -1,6 +1,7 @@
 import os
 import random
 from fuzzywuzzy import fuzz
+import pandas
 
 from groclient import GroClient
 from groclimateclient.constants import CLIMATE_METRICS,CLIMATE_ITEMS, CLIMATE_SOURCES,CMIP6_SOURCES
@@ -36,7 +37,7 @@ class GroClimateClient(object):
             access_token = os.environ.get("GROAPI_TOKEN")
             if access_token is None:
                 raise RuntimeError("$GROAPI_TOKEN environment variable must be set when "
-                                   "GroClient is constructed without the access_token argument")
+                                   "GroClimateClient is constructed without the access_token argument")
         self._api_host = api_host
         self._access_token = access_token
         self._client = GroClient(self._api_host, self._access_token)
@@ -55,14 +56,14 @@ class GroClimateClient(object):
             'resolution',
             'sourceLag']
         """
-        dict = self.lookup('sources', CLIMATE_SOURCES)
+        dict = self._client.lookup('sources', CLIMATE_SOURCES)
         return list(dict.values())
 
     def get_cmip6_sources(self) -> list:
         """Returns a list of all five CMIP6 sources, as list of dicts.
         Returns same schema as self.get_sources(...)
         """
-        dict = self.lookup('sources', CMIP6_SOURCES)
+        dict = self._client.lookup('sources', CMIP6_SOURCES)
         return list(dict.values())
 
     def get_metrics(self):
@@ -292,4 +293,46 @@ class GroClimateClient(object):
 
         if len(searchResults)==0:
             raise Exception("No region match for query "+query)
-        return searchResults[0]
\ No newline at end of file
+        return searchResults[0]
+
+    def add_single_data_series(self, data_series: dict) -> None:
+        """Save a data series object to the GroClient's data_series_list.
+
+        For use with :meth:`~.get_df`.
+
+        Parameters
+        ----------
+        data_series : dict
+            A single data_series object, as returned by :meth:`~.get_data_series` or
+            :meth:`~.find_data_series`.
+            See https://developers.gro-intelligence.com/data-series-definition.html
+
+        Returns
+        -------
+        None
+
+        """
+        if data_series['source_id'] not in CLIMATE_SOURCES:
+            raise Exception("Can't add the following data series, not in the climate tier: "+str(data_series))
+        self._client.add_single_data_series(data_series)
+
+    def clear_data_series_list(self) -> None:
+        """
+        Clear the list of saved data series which have been added with add_single_data_series(...)
+        """
+        self._client._data_series_list = set()
+        self._client._data_series_queue = []
+        self._client._data_frame = pandas.DataFrame()
+
+    def get_df(self, **kwargs):
+        """Call :meth:`~.get_data_points` for each saved data series and return as a combined
+        dataframe.
+
+        Note you must have first called either :meth:`~.add_data_series` or
+        :meth:`~.add_single_data_series` to save data series into the GroClient's data_series_list.
+        You can inspect the client's saved list using :meth:`~.get_data_series_list`.
+
+        See https://developers.gro-intelligence.com/api.html#groclient.GroClient.get_df for full documentation
+        """
+
+        return self._client.get_df(**kwargs)
\ No newline at end of file
